@@ -20,7 +20,7 @@
 #include <config.h>
 #include <panel-applet-gconf.h>
 
-#include <egg-screen-help.h>
+#include <libgnomeui/gnome-help.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
@@ -181,7 +181,7 @@ help_cb (BonoboUIComponent   *uic,
 {
 	GError *error = NULL;
 
-	egg_help_display_on_screen (
+	gnome_help_display_on_screen (
 		"accessx-status.xml", NULL,
 		gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)),
 		&error);
@@ -1024,12 +1024,12 @@ popup_error_dialog (AccessxStatusApplet* sapplet)
 
 	switch (sapplet->error_type) {
 		case ACCESSX_STATUS_ERROR_XKB_DISABLED : 
-			error_txt = g_strdup ("XKB Extenstion is not enabled");
+			error_txt = g_strdup (_("XKB Extension is not enabled"));
 			break;
 
 		case ACCESSX_STATUS_ERROR_UNKNOWN :
 
-		default	: error_txt = g_strdup ("Unknown error");
+		default	: error_txt = g_strdup (_("Unknown error"));
 			  break;				
 	}
 
@@ -1037,7 +1037,7 @@ popup_error_dialog (AccessxStatusApplet* sapplet)
 				   	 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR,
 					 GTK_BUTTONS_CLOSE,
-					 ("Error: %s"),
+					 _("Error: %s"),
 					 error_txt);
 
 	g_signal_connect (G_OBJECT (dialog),
