@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.80 2004/07/26 00:04:47 gowen Exp $ */
+/* $Id: gweather-pref.c,v 1.83.2.1 2004/10/12 14:01:40 markmc Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -28,7 +28,6 @@
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 #include <gconf/gconf-client.h>
-#include <egg-screen-help.h>
 
 #include <libxml/parser.h>
 #include <libxml/tree.h>
@@ -74,6 +73,7 @@ static GConfEnumStringPair speed_unit_enum_map [] = {
 
 static GConfEnumStringPair pressure_unit_enum_map [] = {
     { PRESSURE_UNIT_DEFAULT, "Default" },
+	{ PRESSURE_UNIT_KPA,     "kPa"     },
 	{ PRESSURE_UNIT_HPA,     "hPa"     },
 	{ PRESSURE_UNIT_MB,      "mb"      },
     { PRESSURE_UNIT_MM_HG,   "mmHg"    },
@@ -343,7 +343,8 @@ static void load_locations (GWeatherApplet *gw_applet)
 {
     GtkTreeView *tree = GTK_TREE_VIEW(gw_applet->pref_tree);
     GtkTreeViewColumn *column;
-    GtkCellRenderer *cell_renderer;	
+    GtkCellRenderer *cell_renderer;
+    WeatherLocation *current_location;
         
     /* Add a colum for the locations */
     cell_renderer = gtk_cell_renderer_text_new ();
@@ -353,7 +354,9 @@ static void load_locations (GWeatherApplet *gw_applet)
     gtk_tree_view_set_expander_column (GTK_TREE_VIEW (tree), column);
     
     /* load locations from xml file */
-    gweather_xml_load_locations(tree, gw_applet->gweather_pref.location);
+    current_location = weather_location_clone (gw_applet->gweather_pref.location);
+    gweather_xml_load_locations(tree, current_location);
+    weather_location_free (current_location);
 }
 
 static void
@@ -405,7 +408,7 @@ static void parse_temp_string (const gchar *gconf_str, GWeatherPrefs *prefs)
     }	
     else {
         /* TRANSLATOR: This is the default unit to use for temperature measurements. */
-        /* Valid values are: "K" (Kelvin), "C" (Centigrade) and "F" (Fahrenheit) */
+        /* Valid values are: "K" (Kelvin), "C" (Celsius) and "F" (Fahrenheit) */
         if (gconf_string_to_enum (temp_unit_enum_map, _("DEFAULT_TEMP_UNIT"), &value) ) {
             prefs->temperature_unit = value;
         }
@@ -478,8 +481,9 @@ static void parse_pressure_string (const gchar *gconf_str, GWeatherPrefs *prefs)
     }	
     else {
         /* TRANSLATOR: This is the default unit to use for atmospheric pressure. */
-        /* Valid values are: "hPa" (hectoPascals), "mb" (millibars), "mmHg"  */
-		/* (millimeters of mercury) and "inHg" (inches of mercury) */
+        /* Valid values are: "kPa" (kiloPascals), "hPa" (hectoPascals),
+           "mb" (millibars), "mmHg" (millimeters of mercury) and
+           "inHg" (inches of mercury) */
         if (gconf_string_to_enum (pressure_unit_enum_map, _("DEFAULT_PRESSURE_UNIT"), &value) ) {
             prefs->pressure_unit = value;
         }
@@ -846,7 +850,8 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     gtk_label_set_mnemonic_widget (GTK_LABEL (temp_label), temp_combo);
     gtk_combo_box_append_text (GTK_COMBO_BOX (temp_combo), _("Default"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (temp_combo), _("Kelvin"));
-    gtk_combo_box_append_text (GTK_COMBO_BOX (temp_combo), _("Centigrade"));
+    /* TRANSLATORS: Celsius is sometimes referred Centigrade */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (temp_combo), _("Celsius"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (temp_combo), _("Fahrenheit"));
 	gtk_widget_show (temp_combo);
 		
@@ -888,6 +893,8 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
 	gw_applet->pref_basic_pres_combo = pres_combo;
     gtk_label_set_mnemonic_widget (GTK_LABEL (pres_label), pres_combo);
     gtk_combo_box_append_text (GTK_COMBO_BOX (pres_combo), _("Default"));
+    /* TRANSLATOR: The pressure unit "kiloPascals" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (pres_combo), _("kPa"));
     /* TRANSLATOR: The pressure unit "hectoPascals" */
     gtk_combo_box_append_text (GTK_COMBO_BOX (pres_combo), _("hPa"));
     /* TRANSLATOR: The pressure unit "millibars" */
@@ -1158,7 +1165,7 @@ static void help_cb (GtkDialog *dialog)
 {
     GError *error = NULL;
 
-    egg_help_display_on_screen (
+    gnome_help_display_on_screen (
 		"gweather", "gweather-settings",
 		gtk_window_get_screen (GTK_WINDOW (dialog)),
 		&error);
