@@ -21,7 +21,7 @@
 #include <stickynotes_applet_callbacks.h>
 #include <stickynotes.h>
 
-#include <egg-screen-help.h>
+#include <libgnome/gnome-help.h>
 
 /* Applet Callback : Mouse button press on the applet. */
 gboolean applet_button_cb(GtkWidget *widget, GdkEventButton *event, StickyNotesApplet *applet)
@@ -81,12 +81,30 @@ gboolean applet_save_cb(StickyNotesApplet *applet)
 	return TRUE;
 }
 
-/* Applet Callback : Resize the applet. */
-gboolean applet_change_size_cb(GtkWidget *widget, gint size, StickyNotesApplet *applet)
+/* Applet Callback : Change the panel orientation. */
+void applet_change_orient_cb(PanelApplet *panel_applet, PanelAppletOrient orient, StickyNotesApplet *applet)
 {
+	applet->panel_orient = orient;
+
+	return;
+}
+
+/* Applet Callback : Resize the applet. */
+void applet_size_allocate_cb(GtkWidget *widget, GtkAllocation *allocation, StickyNotesApplet *applet)
+{
+	if ((applet->panel_orient == PANEL_APPLET_ORIENT_UP) || (applet->panel_orient == PANEL_APPLET_ORIENT_DOWN)) {
+	  if (applet->panel_size == allocation->height)
+	    return;
+	  applet->panel_size = allocation->height;
+	} else {
+	  if (applet->panel_size == allocation->width)
+	    return;
+	  applet->panel_size = allocation->width;
+	}
+
 	stickynotes_applet_update_icon(applet);
 
-	return FALSE;
+	return;
 }
 
 /* Applet Callback : Change the applet background. */
@@ -214,7 +232,7 @@ void menu_preferences_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, cons
 void menu_help_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname)
 {
 	GError *error = NULL;
-	egg_help_display_on_screen("stickynotes_applet", "stickynotes-introduction", gtk_widget_get_screen(applet->w_applet), &error);
+	gnome_help_display_on_screen("stickynotes_applet", NULL, gtk_widget_get_screen(applet->w_applet), &error);
 	if (error) {
 		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 							   _("There was an error displaying help: %s"), error->message);
@@ -378,7 +396,7 @@ void preferences_response_cb(GtkDialog *dialog, gint response, gpointer data)
 {
 	if (response == GTK_RESPONSE_HELP) {
 		GError *error = NULL;
-		egg_help_display_on_screen("stickynotes_applet", "stickynotes-advanced-settings", gtk_widget_get_screen(GTK_WIDGET(dialog)), &error);
+		gnome_help_display_on_screen("stickynotes_applet", "stickynotes-advanced-settings", gtk_widget_get_screen(GTK_WIDGET(dialog)), &error);
 		if (error) {
 			GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 								   _("There was an error displaying help: %s"), error->message);
